==> advanced-systemui_0.5.7.tar.gz: advanced-systemui-0.5.7/button_screen_stayslit.c <==
//	Advanced System UI
//	Copyright (c) 2011 Brand Huntsman <brand.huntsman@gmail.com>

#include "window.h"
#include "main.h"
#include "draw.h"
#include "text.h"
#include "config.h"
#include "hardware.h"

//////////////////////////////////////////////////////////////////////////

void draw_screen_stayslit_button( unsigned force, int x, int y ){
	if(force){
		// background for all buttons is cleared by draw_window()
		screenstayslit_button_page = primary_widgets;
	} else if(hw_changes & HW_SCREEN_STAYS_LIT){
		// button background
		x_set_color(bg_color);
		x_fill_rectangle(x, y, 80, 80);
	} else return;

	unsigned cx = x+40, cy = y+40;

	draw_text("screen", 16, fg2_color, cx, cy-14, ALIGN_CENTER, ALIGN_BASELINE, 0);
	draw_text("stays lit", 16, fg2_color, cx, cy+6, ALIGN_CENTER, ALIGN_BASELINE, 0);
	if(hw_screen_stays_lit)
		draw_text("charger", 16, fg1_color, cx, cy+26, ALIGN_CENTER, ALIGN_BASELINE, 0);
	else
		draw_text("never", 16, fg1_color, cx, cy+26, ALIGN_CENTER, ALIGN_BASELINE, 0);

	draw_tap_markers(x, y, 80, 1, 0); // short tap only
}

//////////////////////////////////////////////////////////////////////////

void click_screen_stayslit_button( ){
	if(click.type != CLICK_SHORT) return;

	highlight_selected_area(widget_x, widget_y, 80,80);
	conf_set_screen_stayslit_value(!conf_get_screen_stayslit_value()); // toggle
	hw_screen_stays_lit = (hw_screen_stays_lit ? 0 : 1);

	// redraw button
	x_set_color(bg_color);
	x_fill_rectangle(widget_x, widget_y, 80, 80);
	draw_screen_stayslit_button(1, widget_x, widget_y);
	x_flush();
}

////////////////////////////////////////////////////////////////////////// BUTTON

s_button button_screen_stayslit = {"*stay lit", "/apps/asui_state/bcell_screen_stayslit", draw_screen_stayslit_button, click_screen_stayslit_button, 0};

==> advanced-systemui_0.5.9.tar.gz: advanced-systemui-0.5.9/button_screen_stayslit.c <==
//	Advanced System UI
//	Copyright (c) 2011 Brand Huntsman <brand.huntsman@gmail.com>

#include "window.h"
#include "main.h"
#include "draw.h"
#include "text.h"
#include "config.h"
#include "hardware.h"

//////////////////////////////////////////////////////////////////////////

void draw_screen_stayslit_button( unsigned force, int x, int y ){
	if(force){
		// background for all buttons is cleared by draw_window()
		screenstayslit_button_page = primary_widgets;
	} else if(hw_changes & HW_SCREEN_STAYS_LIT){
		// button background
		x_set_color(secondary_bg_color);
		x_fill_rectangle(x, y, 80, 80);
	} else return;

	unsigned cx = x+40, cy = y+40;

	draw_text("screen", 16, fg2_color, cx, cy-14, ALIGN_CENTER, ALIGN_BASELINE, 0);
	draw_text("stays lit", 16, fg2_color, cx, cy+6, ALIGN_CENTER, ALIGN_BASELINE, 0);
	if(hw_screen_stays_lit)
		draw_text("charger", 16, fg1_color, cx, cy+26, ALIGN_CENTER, ALIGN_BASELINE, 0);
	else
		draw_text("never", 16, fg1_color, cx, cy+26, ALIGN_CENTER, ALIGN_BASELINE, 0);

	draw_tap_markers(x, y, 80, 1, 0); // short tap only
}

//////////////////////////////////////////////////////////////////////////

void click_screen_stayslit_button( ){
	if(click.type != CLICK_SHORT) return;

	highlight_selected_area(widget_x, widget_y, 80,80, 1);
	conf_set_screen_stayslit_value(!conf_get_screen_stayslit_value()); // toggle
	hw_screen_stays_lit = (hw_screen_stays_lit ? 0 : 1);

	// redraw button
	x_set_color(secondary_bg_color);
	x_fill_rectangle(widget_x, widget_y, 80, 80);
	draw_screen_stayslit_button(1, widget_x, widget_y);
	x_flush();
}

////////////////////////////////////////////////////////////////////////// BUTTON

s_button button_screen_stayslit = {"*stay lit", "/apps/asui_state/bcell_screen_stayslit", draw_screen_stayslit_button, click_screen_stayslit_button, 0};
